summaryrefslogtreecommitdiffstats
path: root/kdeui/kpanelextension.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-01-03 04:12:51 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-01-03 04:12:51 +0000
commit560378aaca1784ba19806a0414a32b20c744de39 (patch)
treece0dfd7c3febf2a1adc7603d1019a8be2083c415 /kdeui/kpanelextension.h
parentd4d5af1cdbd3cc65d095e0afc5b1f4260091cf5d (diff)
downloadtdelibs-560378aaca1784ba19806a0414a32b20c744de39.tar.gz
tdelibs-560378aaca1784ba19806a0414a32b20c744de39.zip
Automated conversion for enhanced compatibility with TQt for Qt4 3.4.0 TP1
NOTE: This will not compile with Qt4 (yet), however it does compile with Qt3 git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdelibs@1211081 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kdeui/kpanelextension.h')
-rw-r--r--kdeui/kpanelextension.h20
1 files changed, 10 insertions, 10 deletions
diff --git a/kdeui/kpanelextension.h b/kdeui/kpanelextension.h
index 8fe97956d..7e223f8ac 100644
--- a/kdeui/kpanelextension.h
+++ b/kdeui/kpanelextension.h
@@ -136,7 +136,7 @@ public:
* location in the Window Manager Dock. Please note that the size can not be larger than the
* maxsize given by the handler.
**/
- virtual TQSize sizeHint(Position /*p*/, TQSize maxsize) const { return maxsize; }
+ virtual TQSize tqsizeHint(Position /*p*/, TQSize maxsize) const { return maxsize; }
/**
* Always use this KConfig object to save/load your extensions configuration.
@@ -189,7 +189,7 @@ public:
/**
* @internal
**/
- void setAlignment( Alignment a );
+ void tqsetAlignment( Alignment a );
/**
* @internal
* @since 3.1
@@ -216,7 +216,7 @@ public:
TQPopupMenu* customMenu() const;
/**
- * @return whether or not to set a desktop geometry claiming strut for this panel
+ * @return whether or not to set a desktop tqgeometry claiming strut for this panel
* defaults to true
* @see setReservetrut(bool)
* @since 3.4
@@ -225,9 +225,9 @@ public:
signals:
/**
- * Emit this signal to make the panel relayout all extensions in the dock, when you want
+ * Emit this signal to make the panel retqlayout all extensions in the dock, when you want
* to change the extensions size.
- * The panel is going to relayout all extensions based on their preferred size.
+ * The panel is going to retqlayout all extensions based on their preferred size.
**/
void updateLayout();
@@ -282,9 +282,9 @@ protected:
Position position() const { return _position; }
/**
* @return the extension's alignment. (left/top, center, or right/bottom)
**/
- Alignment alignment() const { return _alignment; }
+ Alignment tqalignment() const { return _tqalignment; }
/**
* @return the extensions orientation. (horizontal or vertical)
@@ -305,11 +305,11 @@ protected:
virtual void positionChange( Position ) {}
/**
* This extension has changed its alignment.
* Reimplement this change handler in order to adjust the look of your
* applet.
**/
- virtual void alignmentChange( Alignment ) {}
+ virtual void tqalignmentChange( Alignment ) {}
/**
* Use this method to set the custom menu for this extensions so that it can be shown
@@ -333,7 +333,7 @@ protected:
private:
Type _type;
Position _position;
- Alignment _alignment;
+ Alignment _tqalignment;
KConfig* _config;
int _actions;
protected:
@@ -282,9 +282,9 @@ protected:
Position position() const { return _position; }
/**
- * @return the extension's alignment. (left/top, center, or right/bottom)
+ * @return the extension's tqalignment. (left/top, center, or right/bottom)
**/
@@ -305,11 +305,11 @@ protected:
virtual void positionChange( Position ) {}
/**
- * This extension has changed its alignment.
+ * This extension has changed its tqalignment.
* Reimplement this change handler in order to adjust the look of your
* applet.